@@ -226,7 +226,7 @@ class CoordinationDriver(object):
         :param group_id: the id of the group to join
         :type group_id: str
         :param capabilities: the capabilities of the joined member
-        :type capabilities: str
+        :type capabilities: object (typically str)
         :returns: None
         :rtype: CoordAsyncResult
         """
@@ -243,6 +243,17 @@ class CoordinationDriver(object):
         """
         raise tooz.NotImplemented
 
+    @staticmethod
+    def delete_group(group_id):
+        """Delete a group asynchronously.
+
+        :param group_id: the id of the group to leave
+        :type group_id: str
+        :returns: Result
+        :rtype: CoordAsyncResult
+        """
+        raise tooz.NotImplemented
+
     @staticmethod
     def get_members(group_id):
         """Return the list of all members ids of the specified group
@@ -274,7 +285,7 @@ class CoordinationDriver(object):
         :param group_id: the id of the group of the current member
         :type group_id: str
         :param capabilities: the capabilities of the updated member
-        :type capabilities: str
+        :type capabilities: object (typically str)
         :returns: None
         :rtype: CoordAsyncResult
         """
@@ -329,21 +340,33 @@ class CoordAsyncResult(object):
         """Returns True if the task is done, False otherwise."""
 
 
-def get_coordinator(backend_url, member_id):
+def get_coordinator(backend_url, member_id, **kwargs):
     """Initialize and load the backend.
 
     :param backend_url: the backend URL to use
     :type backend: str
     :param member_id: the id of the member
     :type member_id: str
+    :param kwargs: additional coordinator options (these take precedence over
+                   options of the **same** name found in the ``backend_url``
+                   arguments query string)
     """
     parsed_url = netutils.urlsplit(backend_url)
     parsed_qs = six.moves.urllib.parse.parse_qs(parsed_url.query)
+    if kwargs:
+        options = {}
+        for (k, v) in six.iteritems(kwargs):
+            options[k] = [v]
+        for (k, v) in six.iteritems(parsed_qs):
+            if k not in options:
+                options[k] = v
+    else:
+        options = parsed_qs
     return driver.DriverManager(
         namespace=TOOZ_BACKENDS_NAMESPACE,
         name=parsed_url.scheme,
         invoke_on_load=True,
-        invoke_args=(member_id, parsed_url, parsed_qs)).driver
+        invoke_args=(member_id, parsed_url, options)).driver
 
 
 class ToozError(Exception):
@@ -403,3 +426,10 @@ class MemberNotJoined(ToozError):
         self.member_id = member_id
         super(MemberNotJoined, self).__init__("Member %s has not joined %s" %
                                               (member_id, group_id))
+
+
+class GroupNotEmpty(ToozError):
+    "Exception raised when the caller try to delete a group with members."
+    def __init__(self, group_id):
+        self.group_id = group_id
+        super(GroupNotEmpty, self).__init__("Group %s is not empty" % group_id)
